@@ -127,14 +127,17 @@ activate_action_about (GtkAction *action,
 {
 	GooWindow        *window = data;
 	static GtkWidget *about = NULL;
+#ifndef HAVE_GTK_2_5
 	GdkPixbuf        *logo;
+#endif
 	const char       *authors[] = {
 		"Paolo Bacchilega <paolo.bacchilega@libero.it>", 
 		NULL
 	};
-	const char       *documenters [] = {
-		NULL
-	};
+	/*
+	  const char       *documenters [] = {
+	  NULL
+	  };*/
 	const char       *translator_credits = _("translator_credits");
 
 	if (about != NULL) {
@@ -142,18 +145,38 @@ activate_action_about (GtkAction *action,
 		return;
 	}
 
+#ifdef HAVE_GTK_2_5
+
+	about = gtk_about_dialog_new ();
+	g_object_set (about,
+		      "name",  _("Goobox"),
+		      "version", VERSION,
+		      "copyright", "Copyright \xc2\xa9 2004 Free Software Foundation, Inc.",
+		      "comments", _("CD player and ripper"),
+		      "authors", authors,
+		      /*"documenters", documenters,*/
+		      "translator_credits", strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+		      "website", NULL,
+		      "website_label", NULL,
+		      "license", NULL,
+		      NULL);
+
+#else
+
 	logo = gdk_pixbuf_new_from_file (PIXMAPSDIR "/goobox.png", NULL);
 	about = gnome_about_new (_("Goobox"), 
 				 VERSION,
 				 "Copyright \xc2\xa9 2004 Free Software Foundation, Inc.",
 				 _("CD player and ripper"),
 				 authors,
-				 documenters,
+				 NULL /*documenters*/,
 				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 				 logo);
 	if (logo != NULL)
                 g_object_unref (logo);
 
+#endif
+
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (about), TRUE);
 	gtk_window_set_transient_for (GTK_WINDOW (about), 
 				      GTK_WINDOW (window));
@@ -163,7 +186,7 @@ activate_action_about (GtkAction *action,
 			  G_CALLBACK (gtk_widget_destroyed), 
 			  &about);
 
-	gtk_widget_show_all (about);
+	gtk_widget_show (about);
 }
 
 
@@ -171,8 +194,7 @@ void
 activate_action_quit (GtkAction *action, 
 		      gpointer   data)
 {
-	gtk_widget_destroy (GTK_WIDGET (main_window));
-	bonobo_main_quit ();
+	goo_window_close (GOO_WINDOW (data));
 }
 
 
@@ -238,3 +260,35 @@ activate_action_edit_cddata (GtkAction *action,
 {
 	goo_window_edit_cddata (GOO_WINDOW (data));
 }
+
+
+void
+activate_action_pick_cover_from_disk (GtkAction *action, 
+				      gpointer   data)
+{
+	goo_window_pick_cover_from_disk (GOO_WINDOW (data));
+}
+
+
+void
+activate_action_remove_cover (GtkAction *action, 
+			      gpointer   data)
+{
+	goo_window_remove_cover (GOO_WINDOW (data));
+}
+
+
+void
+activate_action_search_cover_on_internet (GtkAction *action, 
+					  gpointer   data)
+{
+	goo_window_search_cover_on_internet (GOO_WINDOW (data));
+}
+
+
+void
+activate_action_toggle_visibility (GtkAction *action, 
+				   gpointer   data)
+{
+	goo_window_toggle_visibility (GOO_WINDOW (data));
+}
