@@ -58,6 +58,7 @@ struct _GooPlayerCDPrivateData {
 	char            *artist;
 	char            *title;
 	char            *genre;
+	int              year;
 	guint            update_state_id;
 
 	guint            update_progress_id;
@@ -309,6 +310,7 @@ goo_player_cd_empty_list (GooPlayer *player)
 	goo_player_set_current_song (player, -1);
 	goo_player_set_title (player, NULL);
 	goo_player_set_subtitle (player, NULL);
+	goo_player_set_year (player, 0);
 }
 
 
@@ -880,8 +882,11 @@ cddb_slave_listener_event_cb (BonoboListener    *listener,
 	g_free (priv->genre);
 	priv->genre = cddb_slave_client_get_genre (priv->cddb_client, priv->discid);
 
+	priv->year = cddb_slave_client_get_year (priv->cddb_client, priv->discid);
+
 	goo_player_set_title (player, priv->title);
 	goo_player_set_subtitle (player, priv->artist);
+	goo_player_set_year (player, priv->year);
 
 	for (scan = priv->tracks, i = 0; scan; scan = scan->next, i++) {
 		TrackInfo *track = scan->data;
@@ -996,11 +1001,7 @@ goo_player_cd_new (const char *location)
 const char *
 goo_player_cd_get_discid (GooPlayerCD *player)
 {
-	/*
-	if (goo_player_get_is_busy (GOO_PLAYER (player)))
-		return NULL;
-		else*/
-		return player->priv->discid;
+	return player->priv->discid;
 }
 
 
@@ -1010,11 +1011,6 @@ goo_player_cd_get_track (GooPlayerCD *player,
 {
 	GList *scan;
 
-	/*
-	if (goo_player_get_is_busy (GOO_PLAYER (player)))
-		return NULL;
-	*/
-
 	for (scan = player->priv->tracks; scan; scan = scan->next) {
 		TrackInfo *track = scan->data;
 		if (track->number == n)
@@ -1028,42 +1024,26 @@ goo_player_cd_get_track (GooPlayerCD *player,
 GList *
 goo_player_cd_get_tracks (GooPlayerCD *player)
 {
-	/*
-	if (goo_player_get_is_busy (GOO_PLAYER (player)))
-		return NULL;
-		else*/
-		return track_list_dup (player->priv->tracks);
+	return track_list_dup (player->priv->tracks);
 }
 
 
 const char *
 goo_player_cd_get_artist (GooPlayerCD *player)
 {
-	/*
-	if (goo_player_get_is_busy (GOO_PLAYER (player)))
-		return NULL;
-		else*/
-		return player->priv->artist;
+	return player->priv->artist;
 }
 
 
 const char *
 goo_player_cd_get_album (GooPlayerCD *player)
 {
-	/*
-	if (goo_player_get_is_busy (GOO_PLAYER (player)))
-		return NULL;
-		else*/
-		return player->priv->title;
+	return player->priv->title;
 }
 
 
 const char *
 goo_player_cd_get_genre (GooPlayerCD *player)
 {
-	/*
-	if (goo_player_get_is_busy (GOO_PLAYER (player)))
-		return NULL;
-		else*/
-		return player->priv->genre;
+	return player->priv->genre;
 }
